# Generated by Django 3.2.8 on 2021-10-18 21:21

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
    ]

    operations = [
        migrations.CreateModel(
            name='AuditLog',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('user_agent', models.CharField(max_length=255)),
                ('ip_address', models.GenericIPAddressField(null=True, verbose_name='IP Address')),
                ('content_type', models.CharField(max_length=200, verbose_name='Content Type')),
                ('query_string', models.TextField(verbose_name='Query String')),
                ('http_method', models.CharField(max_length=20, verbose_name='HTTP Method')),
                ('http_referer', models.CharField(max_length=500, verbose_name='HTTP Method')),
                ('path_info', models.CharField(max_length=255, verbose_name='Path')),
                ('request_data', models.TextField(null=True)),
                ('response_status_code', models.IntegerField(null=True)),
                ('response_reason_phrase', models.TextField()),
                ('attempt_time', models.DateTimeField(auto_now_add=True)),
                ('user', models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, to=settings.AUTH_USER_MODEL)),
            ],
            options={
                'ordering': ['-attempt_time'],
            },
        ),
    ]



from dj_audit import settings
from dj_audit.models import AuditLog


class AuditMiddleware:

    def __init__(self, get_response) -> None:
        self.get_response = get_response

    def __call__(self, request, *args, **kwargs):
        response = self.process_response(request)
        return response

    def process_response(self, request, response=None):
        response = self.get_response(request)

        if settings.DISABLE_AUDIT_LOG:
            return response

        if not request.method in ('HEAD', 'OPTIONS', 'TRACE'):
            if hasattr(request, 'user') and request.user.is_authenticated:
                user = request.user
            else:
                user = None

            log_data = {
                'user_agent': request.META.get('HTTP_USER_AGENT', ''),
                'ip_address': request.META.get('REMOTE_ADDR', ''),
                'user': user,
                'content_type': request.META.get('CONTENT_TYPE', ''),
                'query_string': request.META.get('QUERY_STRING', ''),
                'http_method': request.method,
                'http_referer': request.META.get('HTTP_REFERER', ''),
                'path_info': request.path_info,
                'request_data': request.body.decode('utf-8'),
                'response_status_code': response.status_code,
                'response_reason_phrase': response.reason_phrase
            }

            AuditLog.objects.create(**log_data)

        return response



from django.db import models
from django.contrib.auth import get_user_model


class AuditLog(models.Model):
    """ Audit log """

    user_agent = models.CharField(max_length=255,)
    ip_address = models.GenericIPAddressField(
        verbose_name="IP Address", null=True,)
    user = models.ForeignKey(
        to=get_user_model(), null=True, on_delete=models.CASCADE)
    content_type = models.CharField(
        verbose_name="Content Type", max_length=200,)
    query_string = models.TextField(
        verbose_name="Query String")
    http_method = models.CharField(
        verbose_name="HTTP Method", max_length=20,)
    http_referer = models.CharField(
        verbose_name="HTTP Method", max_length=500,)
    path_info = models.CharField(verbose_name="Path", max_length=255,)
    request_data = models.TextField(null=True)
    response_status_code = models.IntegerField(null=True)
    response_reason_phrase = models.TextField()
    attempt_time = models.DateTimeField(auto_now_add=True,)

    class Meta:
        ordering = ["-attempt_time"]

    def __str__(self) -> str:
        """ unicode value for this model """
        return f'{self.user}, {self.attempt_time}'



import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name='dj_audit',
    version='0.0.2',
    author="Tairu Oluwafemi Emmanuel",
    author_email="developer.emmarex@gmail.com",
    description="",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/Emmarex/django-audit",
    download_url="",
    keywords=['Django Audit', 'Audit', 'audit trail'],
    packages=setuptools.find_packages(),
    python_requires='~=3.6',
    install_requires=["Django"],
    classifiers=[
        "Natural Language :: English",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "License :: OSI Approved :: Apache Software License",
        "Development Status :: 4 - Beta",
        # "Development Status :: 6 - Mature",
        "Intended Audience :: Developers",
        "Framework :: Django",
        "Framework :: Django :: 3.0",
        "Framework :: Django :: 3.1",
        "Framework :: Django :: 3.2"
    ],
)



from django.contrib import admin
from dj_audit.models import AuditLog


@admin.register(AuditLog)
class AuditLogAdmin(admin.ModelAdmin):
    list_display = (
        'user_agent', 'ip_address', 'user', 'content_type', 'query_string',
        'http_method', 'http_referer', 'path_info', 'request_data',
        'response_status_code', 'response_reason_phrase', 'attempt_time'
    )
    list_filter = ('user', 'http_method')
    search_fields = ('user__username', 'ip_address')
